Method: GeoRuby::SimpleFeatures::Envelope#extend
- Defined in:
- lib/geo_ruby/simple_features/envelope.rb
#extend(envelope) ⇒ Object
Merges the argument with the current evelope and sends back a new envelope without changing the current one
26 27 28 29 30 31 |
# File 'lib/geo_ruby/simple_features/envelope.rb', line 26 def extend(envelope) e = Envelope.from_points([Point.from_x_y(lower_corner.x,lower_corner.y), Point.from_x_y(upper_corner.x,upper_corner.y)],srid,with_z) e.extend!(envelope) e end |